Struct caesar_core::relay::appstate::AppState
source · pub struct AppState {
pub rooms: HashMap<String, Room>,
pub transfers: Vec<TransferResponse>,
}Expand description
State of the application.
This structure holds the state of the application, which includes the rooms and the transfers.
Fields
rooms: HashMap<String, Room>Map of rooms, where the key is the room’s ID and the value is the room itself.
transfers: Vec<TransferResponse>Vector of transfers.
Implementations